@@ -537,6 +537,15 @@ _FUNCTIONS = [
      '``ST_Distance_Spheroid``, but less accurate. PostGIS versions '
      'prior to 1.5 only implemented for points.'),
 
+    ('ST_DistanceSphere', None,
+     'Returns minimum distance in meters between two lon/lat points. Uses '
+     'a spherical earth and radius derived from the spheroid defined by the '
+     'SRID. Faster than ST_DistanceSpheroid, but less accurate. PostGIS '
+     'Versions prior to 1.5 only implemented for points. Availability: 1.5 - '
+     'support for other geometry types besides points was introduced. Prior '
+     'versions only work with points. Changed: 2.2.0 In prior versions this '
+     'used to be called ST_Distance_Sphere'),
+
     ('ST_DFullyWithin', None,
      'Returns ``True`` if all of the geometries are within the specified '
      'distance of one another'),
@@ -720,11 +729,20 @@ _SQLITE_FUNCTIONS = {
 }
 
 
-def _compiles(cls, fn):
-    def _compile(element, compiler, **kw):
+# Default handlers are required for SQLAlchemy < 1.1
+# See more details in https://github.com/geoalchemy/geoalchemy2/issues/213
+def _compiles_default(cls):
+    def _compile_default(element, compiler, **kw):
+        return "{}({})".format(cls, compiler.process(element.clauses, **kw))
+    compiles(globals()[cls])(_compile_default)
+
+
+def _compiles_sqlite(cls, fn):
+    def _compile_sqlite(element, compiler, **kw):
         return "{}({})".format(fn, compiler.process(element.clauses, **kw))
-    compiles(globals()[cls], "sqlite")(_compile)
+    compiles(globals()[cls], "sqlite")(_compile_sqlite)
 
 
 for cls, fn in _SQLITE_FUNCTIONS.items():
-    _compiles(cls, fn)
+    _compiles_default(cls)
+    _compiles_sqlite(cls, fn)
