@@ -40,6 +40,10 @@ class TestWKTElement():
             u'ST_GeomFromText_2': -1
         }
 
+    def test_attribute_error(self):
+        e = WKTElement('POINT(1 2)')
+        assert not hasattr(e, 'foo')
+
     def test_pickle_unpickle(self):
         import pickle
         e = WKTElement('POINT(1 2)', srid=3, extended=True)
@@ -258,6 +262,10 @@ class TestWKBElement():
             u'ST_GeomFromWKB_2': -1
         }
 
+    def test_attribute_error(self):
+        e = WKBElement(b'\x01\x02')
+        assert not hasattr(e, 'foo')
+
     def test_function_str(self):
         e = WKBElement(b'\x01\x02')
         assert isinstance(str(e), str)
