@@ -79,7 +79,7 @@ class IndexTestWithoutSchema(Base):
 session = sessionmaker(bind=engine)()
 
 postgis_version = session.execute(func.postgis_version()).scalar()
-if not postgis_version.startswith('2.'):
+if postgis_version.startswith('1.'):
     # With PostGIS 1.x the AddGeometryColumn and DropGeometryColumn
     # management functions should be used.
     Lake.__table__.c.geom.type.management = True
@@ -98,8 +98,8 @@ else:
             self.rast = rast
 
 postgis2_required = pytest.mark.skipif(
-    not postgis_version.startswith('2.'),
-    reason="requires PostGIS 2.x",
+    postgis_version.startswith('1.'),
+    reason="requires PostGIS 2 or higher",
 )
 
 
@@ -256,7 +256,7 @@ class TestSelectBindParam():
         rows = results.fetchall()
         geom = rows[0][1]
         assert isinstance(geom, WKBElement)
-        assert geom.extented
+        assert geom.extended is True
 
         s = Lake.__table__.select().where(Lake.__table__.c.geom == bindparam('geom'))
         results = self.conn.execute(s, geom=geom)
@@ -288,33 +288,33 @@ class TestInsertionORM():
         # With PostGIS 2.0:
         # DataError: (DataError) Geometry SRID (0) does not match column SRID
         # (4326)
-        l = Lake('LINESTRING(0 0,1 1)')
-        session.add(l)
+        lake = Lake('LINESTRING(0 0,1 1)')
+        session.add(lake)
 
         with pytest.raises((DataError, IntegrityError)):
             session.flush()
 
     def test_WKTElement(self):
-        l = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
-        session.add(l)
+        lake = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
+        session.add(lake)
         session.flush()
-        session.expire(l)
-        assert isinstance(l.geom, WKBElement)
-        wkt = session.execute(l.geom.ST_AsText()).scalar()
+        session.expire(lake)
+        assert isinstance(lake.geom, WKBElement)
+        wkt = session.execute(lake.geom.ST_AsText()).scalar()
         assert wkt == 'LINESTRING(0 0,1 1)'
-        srid = session.execute(l.geom.ST_SRID()).scalar()
+        srid = session.execute(lake.geom.ST_SRID()).scalar()
         assert srid == 4326
 
     def test_WKBElement(self):
         shape = LineString([[0, 0], [1, 1]])
-        l = Lake(from_shape(shape, srid=4326))
-        session.add(l)
+        lake = Lake(from_shape(shape, srid=4326))
+        session.add(lake)
         session.flush()
-        session.expire(l)
-        assert isinstance(l.geom, WKBElement)
-        wkt = session.execute(l.geom.ST_AsText()).scalar()
+        session.expire(lake)
+        assert isinstance(lake.geom, WKBElement)
+        wkt = session.execute(lake.geom.ST_AsText()).scalar()
         assert wkt == 'LINESTRING(0 0,1 1)'
-        srid = session.execute(l.geom.ST_SRID()).scalar()
+        srid = session.execute(lake.geom.ST_SRID()).scalar()
         assert srid == 4326
 
     @postgis2_required
@@ -357,10 +357,10 @@ class TestPickle():
         metadata.drop_all()
 
     def _create_one_lake(self):
-        l = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
-        session.add(l)
+        lake = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
+        session.add(lake)
         session.flush()
-        return l.id
+        return lake.id
 
     def test_pickle_unpickle(self):
         import pickle
@@ -375,7 +375,7 @@ class TestPickle():
         unpickled = pickle.loads(pickled)
         assert unpickled.geom.srid == 4326
         assert str(unpickled.geom) == data_desc
-        assert unpickled.geom.extended
+        assert unpickled.geom.extended is True
         assert unpickled.geom.name == 'ST_GeomFromEWKB'
 
 
@@ -390,10 +390,10 @@ class TestCallFunction():
         metadata.drop_all()
 
     def _create_one_lake(self):
-        l = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
-        session.add(l)
+        lake = Lake(WKTElement('LINESTRING(0 0,1 1)', srid=4326))
+        session.add(lake)
         session.flush()
-        return l.id
+        return lake.id
 
     def _create_one_poi(self):
         p = Poi('POINT(5 45)')
@@ -566,7 +566,7 @@ class TestReflection():
             autoload_with=engine)
         type_ = t.c.geom.type
         assert isinstance(type_, Geometry)
-        if not postgis_version.startswith('2.'):
+        if postgis_version.startswith('1.'):
             assert type_.geometry_type == 'GEOMETRY'
             assert type_.srid == -1
         else:
